@@ -1,5 +1,5 @@
 /* main.c - initialize think & read commandline args
-   Copyright (C) 1999 Peter Teichman
+   Copyright (C) 1999, 2000 Peter Teichman
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -16,21 +16,32 @@
    Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, 
    USA.  */
 
+#ifdef HAVE_CONFIG_H
 #include <config.h>
-#include <gnome.h>
-#include "think.h"
+#endif
 
-static void think_quit (GtkWidget *widget, gpointer data);
+#include <gnome.h>
+#include <glade/glade.h>
+
+#include "support.h"
+#include "think.h"
 
 int 
 main (int argc, char *argv[])
 {
-	GtkWidget *main_window;
+	GtkWidget *outline;
 	gchar *filename = NULL;
 	char **args;
 	poptContext ctx;
 
-	gnome_init_with_popt_table ("think", VERSION, argc, argv, NULL, 0, &ctx);
+#ifdef ENABLE_NLS
+	bindtextdomain (PACKAGE, PACKAGE_LOCALE_DIR);
+	textdomain (PACKAGE);
+#endif
+
+	glade_gnome_init ();
+	gnome_init_with_popt_table ("think", VERSION, argc, argv,
+				    NULL, 0, &ctx);
 	args = (char **)poptGetArgs(ctx);
 
 	if (args) 
@@ -38,10 +49,9 @@ main (int argc, char *argv[])
 
 	poptFreeContext (ctx);
 
-	main_window = think_window_new (filename);
-	gtk_widget_show (main_window);
+	outline = think_window_new (filename);
+	gtk_widget_show (outline);
 
 	gtk_main();
-  
 	return 0;
 }
