@@ -1,5 +1,5 @@
-/* outline.h - declarations to populate a ctree from an emacs outline-mode file
-   Copyright (C) 1999 Peter Teichman
+/* outline.h - declarations to populate a ctree from an xml file
+   Copyright (C) 1999, 2000 Peter Teichman
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 #include <glib.h>
 
-void outline_load_xml (gchar *filename, GNode **root);
-void outline_save_xml (gchar *filename, GNode *root);
+gpointer outline_load_xml (gchar *filename, GNode **root);
+void     outline_save_xml (gchar *filename, GNode *root);
 
 #endif /* __OUTLINE_H__ defined */
