@@ -1,7 +1,20 @@
-/* implementation of ThinkOutlineContent
- * 
- * Author: Peter Teichman <pat4@acpub.duke.edu>
- */
+/* think-outline-content.c: base content item for a ThinkOutline
+   Copyright (C) 1999, 2000 Peter Teichman
+
+   This program is free software; you can redistribute it and/or modify
+   it under the terms of the GNU General Public License as published by
+   the Free Software Foundation; either version 2, or (at your option)
+   any later version.
+
+   This program is distributed in the hope that it will be useful,
+   but WITHOUT ANY WARRANTY; without even the implied warranty of
+   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+   GNU General Public License for more details.
+
+   You should have received a copy of the GNU General Public License
+   along with this program; if not, write to the Free Software
+   Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, 
+   USA.  */
 
 #include <config.h>
 #include <gnome.h>
@@ -27,6 +40,7 @@ static void item_drop_after  (ThinkOutlineContent *content,
 			      ThinkOutlineContent *dropped);
 static void item_drop_before (ThinkOutlineContent *content, 
 			      ThinkOutlineContent *dropped);
+static void image_events (GdkImlibImage *image, GdkEvent *event, gpointer data);
 
 static GnomeCanvasGroupClass *think_outline_content_parent_class;
 
@@ -238,7 +252,7 @@ think_outline_content_new_with_data (gpointer data,
 gpointer
 think_outline_content_get_data (ThinkOutlineContent *content)
 {
-	g_return_if_fail (content != NULL);
+	g_return_val_if_fail (content != NULL, NULL);
 
 	return content->priv->data;
 }
@@ -264,7 +278,7 @@ think_outline_content_set_draw_func (ThinkOutlineContent *content,
 guint
 think_outline_content_expanded (ThinkOutlineContent *content)
 {
-	g_return_if_fail (content != NULL);
+	g_return_val_if_fail (content != NULL, 0);
 
 	return content->priv->expanded;
 }
@@ -280,6 +294,10 @@ think_outline_content_expand (ThinkOutlineContent *content)
 {
 	g_return_if_fail (content != NULL);
 
+	if (!content->priv->expanded)
+		gtk_signal_emit (GTK_OBJECT (content),
+				 gtk_signal_lookup ("expand", 
+						    GTK_OBJECT_TYPE (content)));
 	content_expand_real (content);
 }
 
@@ -294,16 +312,29 @@ think_outline_content_collapse (ThinkOutlineContent *content)
 {
 	g_return_if_fail (content != NULL);
 
+	if (content->priv->expanded)
+		gtk_signal_emit (GTK_OBJECT (content),
+				 gtk_signal_lookup ("collapse", 
+						    GTK_OBJECT_TYPE (content)));
 	content_collapse_real (content);
 }
 
 static void
 expanded_toggle (ThinkOutlineContent *content)
 {
-	if (content->priv->expanded)
+	if (content->priv->expanded) {
+		if (content->priv->expanded)
+			gtk_signal_emit (GTK_OBJECT (content),
+					 gtk_signal_lookup ("collapse", 
+							    GTK_OBJECT_TYPE (content)));
 		content->priv->expanded = 0;
-	else
+	} else {
+		if (!content->priv->expanded)
+			gtk_signal_emit (GTK_OBJECT (content),
+					 gtk_signal_lookup ("expand", 
+							    GTK_OBJECT_TYPE (content)));
 		content->priv->expanded = 1;
+	}
 }
 
 void
