@@ -1,5 +1,5 @@
 /* think.h
-   Copyright (C) 1999 Peter Teichman
+   Copyright (C) 1999, 2000 Peter Teichman
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -34,8 +34,9 @@ struct _ThinkNode
 	gboolean is_done;
 };
 
+GNode *new_think_gnode (void);
 ThinkNode *think_node_new (void);
-GnomeCanvasItem *make_outline_node (GnomeCanvasGroup *group, 
-				    ThinkOutlineContent *content);
+GnomeCanvasItem *think_render_outline_content (GnomeCanvasGroup *group, 
+					       ThinkOutlineContent *content);
 
 #endif /* __THINK_H__ defined */
